# Event Systems
- A collection of thread-safe event systems which components can use to subscribe and post to other components.
- Two implementations are provided currently: 
    - InternalEventSystem (instance based)
    - SharedEventSystem (singleton based)
- install: `pip install event-systems`